<?php
/*******************************************************************************
 * Stellware - Jugendhilfe Management System                                   *
 *                                                                             *
 * Dieses Programm ist Freie Software. Sie koennen es unter den Bedingungen    *
 * der GNU General Public License (GPL), wie von der Free Software Foundation  *
 * veroeffentlicht, weitergeben und/oder modifizieren, entweder gemaess        *
 * Version 2 der Lizenz oder, wenn Sie das wuenschen, nach jeder spaeteren     *
 * Version.                                                                    *
 *                                                                             *
 * Die Veroeffentlichung dieses Programmes erfolgt in der Hoffnung, dass es    *
 * Ihnen von Nutzen sein wird, aber ohne irgendeine Garantie, auch ohne die    *
 * implizite Garantie der Marktreife oder Verwendbarkeit fuer irgendeinen      *
 * bestimmten Zweck. Details finden Sie in der GNU General Public License in   *
 * der Datei 'gpl.txt' im Verzeichnis 'doc'.                                   *
 *                                                                             *
 *  http://www.stellware.de                                                    *
 *******************************************************************************
 *
 * $Id: bereit_reqdat.inc.php 2699 2017-02-12 16:31:55Z dschniegler $
 *
 */

/* Aufbereitung der Request-Daten fr die Bereitschaftsplanung
 *  Setzt $jahr (+optional $monat) bzw. $von + $bis in verschiedenen Formaten
 *  und daraus $datumanfang/$datumende
 * (genutzt in bereit.php und bereit_pr.php)
 */
 
if (isset($_REQUEST['jahr']) && 
	intval($_REQUEST['jahr']) >= 1990 &&
	intval($_REQUEST['jahr']) <= 2100) {
	$jahr = intval($_REQUEST['jahr']);
} else {
	$jahr = date('Y');
}
if (isset($_REQUEST['monat']) && 
	intval($_REQUEST['monat']) >= 01 &&
	intval($_REQUEST['monat']) <= 12) {
	$monat = intval($_REQUEST['monat']);
} else {
	$monat = 0;
}
$von = (isset($_REQUEST['von'])) ? $_REQUEST['von'] : "";
$bis = (isset($_REQUEST['bis'])) ? $_REQUEST['bis'] : "";

$alle = (isset($_REQUEST['alle'])) ? (int)$_REQUEST['alle'] : 0;


$datumanfang = 0;
if (preg_match("/^[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,4}/", $von)) {
	$dattmp = explode(".", $von);
	if (checkdate($dattmp[1], $dattmp[0], $dattmp[2])) {
		$datumanfang = mktime(0,0,0, $dattmp[1], $dattmp[0], $dattmp[2]);
	}
} elseif (preg_match("/^[0-9]{1,2}[\/\-][0-9]{1,4}$/", $von)) {
	if (strpos($von, "/") > 0) {
		$dattmp = explode('/',$von);
	} else {
		$dattmp = explode('-',$von);
	}
	if (checkdate($dattmp[0], '01', $dattmp[1])) {
		$datumanfang = mktime(0,0,0, $dattmp[0], '01', $dattmp[1]);
	}
} elseif (preg_match("/^[1-2][0-9][0-9][0-9][wW][0-5][0-9]$/", $von)) {
	$datumanfang = strtotime($von);
} elseif (preg_match("/^[0-5][0-9][wW][1-2][0-9][0-9][0-9]$/", $von)) {
	$datumanfang = strtotime(substr($von,3,4).'W'.substr($von,0,2));
} 

if ($datumanfang == 0) {
	if ($monat != 0) {
		$datumanfang = mktime(0, 0, 0, $monat, '01', $jahr);
		$von="";
	} elseif (($datumanfang = strtotime($von)) === false) {
		// Hinweis: wenn Jahr ber Parameter gesetzt dann ganzes Jahr, sonst von aktuellem Monat
		if (isset($_REQUEST['jahr'])) {
			$datumanfang = getFirstKW($jahr);
		} else {
			$datumanfang = mktime(0, 0, 0, date('m'), '01', date('Y'));
		}
		$von="";
	}
}

$datumanfang = getWochenBeginn($datumanfang);

// Anfang Druckausgabe immer auf den Wochenbeginn setzen
$datumw = strtotime(date('Y',$datumanfang).'W'.date('W',$datumanfang));
// Beachtung Spezialfall Jahreswechsel (insb. bei 53 KW)
if ($datumw > $datumanfang) {
	$datumw = strtotime((date('Y',$datumanfang) - 1).'W52');
}

$datumende = 0;
if (preg_match("/^[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,4}/", $bis)) {
	$dattmp = explode(".", $bis);
	if (checkdate($dattmp[1], $dattmp[0], $dattmp[2])) {
		$datumende = mktime(0,0,0, $dattmp[1], $dattmp[0], $dattmp[2]);
	}
} elseif (preg_match("/^[0-9]{1,2}[\/\-][0-9]{1,4}$/", $bis)) {
	if (strpos($bis, "/") > 0) {
		$dattmp = explode('/',$bis);
	} else {
		$dattmp = explode('-',$bis);
	}
	if (checkdate($dattmp[0], '01', $dattmp[1])) {
		$datumende = mktime(0,0,0, $dattmp[0], '01', $dattmp[1]);
		$datumende = mktime(0, 0, 0, date('m',$datumende), date('t',$datumende), date('Y',$datumende));
	}
} elseif (preg_match("/^[1-2][0-9][0-9][0-9][wW][0-5]{,1}[0-9]$/", $bis)) {
	$datumende = strtotime($bis.' +6 days');
} elseif (preg_match("/^[0-5][0-9][wW][1-2][0-9][0-9][0-9]$/", $bis)) {
	$datumende = strtotime(substr($bis,3,4).'W'.substr($bis,0,2).' +6 days');
}
if ($datumende == 0) {
	if ($monat != 0) {
		$datumende = mktime(0, 0, 0, $monat, '01', $jahr);
		$datumende = mktime(0, 0, 0, date('m',$datumende), date('t',$datumende), date('Y',$datumende));
		$bis="";
	} elseif (($datumende = strtotime($bis)) === false) {
		// Hinweis: wenn Jahr ber Parameter gesetzt dann ganzes Jahr, sonst bis nchsten Monat
		if (isset($_REQUEST['jahr'])) {
			$datumende = mktime(0, 0, 0, 12, 31, $_REQUEST['jahr']);
		} else {
			$datumende = mktime(0, 0, 0, date('m') + 1, '01', date('Y'));
			$datumende = mktime(0, 0, 0, date('m',$datumende), date('t',$datumende), date('Y',$datumende));
		}
		$bis="";
	}
}

$datumende = getWochenEnde($datumende);

if ($datumende < $datumanfang) {
	$datumende = $datumanfang;
}
 
?>
