<?php
/*******************************************************************************
 * Stellware - Jugendhilfe Management System                                   *
 *                                                                             *
 * Dieses Programm ist Freie Software. Sie koennen es unter den Bedingungen    *
 * der GNU General Public License (GPL), wie von der Free Software Foundation  *
 * veroeffentlicht, weitergeben und/oder modifizieren, entweder gemaess        *
 * Version 2 der Lizenz oder, wenn Sie das wuenschen, nach jeder spaeteren     *
 * Version.                                                                    *
 *                                                                             *
 * Die Veroeffentlichung dieses Programmes erfolgt in der Hoffnung, dass es    *
 * Ihnen von Nutzen sein wird, aber ohne irgendeine Garantie, auch ohne die    *
 * implizite Garantie der Marktreife oder Verwendbarkeit fuer irgendeinen      *
 * bestimmten Zweck. Details finden Sie in der GNU General Public License in   *
 * der Datei 'gpl.txt' im Verzeichnis 'doc'.                                   *
 *                                                                             *
 *  http://www.stellware.de                                                    *
 *******************************************************************************
 *
 * $Id: kal.inc.php 2926 2018-12-19 16:04:31Z tfreudenberg $
 *
 */

 /* Datei befindet sich in inc - Dateiname und Verzeichnis entfernen */
 $pfad = substr(__FILE__, 0, strlen(__FILE__) - 15);

 /*
  * Diese Funktion gibt eine Tabelle mit Zeiten aus. Jede ausgegebene Zeile
  * repraesentiert 15 Minuten.Erwartet werden die folgenden Argumente:
  *  $start - Startzeit
  *  $ende  - Endzeit
  */
 function kal_tabelle_zeit($start, $ende, $font_size_header = 10)
 {
   /* Tabelleninitialisierung ausgeben und Spaltenkopf */
   echo "<table width=\"50\" border=\"0\" cellspacing=\"0\" ";
   echo "cellpadding=\"0\">\n<tr>";

   echo "<th style=\"text-align:center;font-size:".$font_size_header."pt\">";
   echo"Zeit</th></tr>\n";

   /* waagerechte gruene Linie */
   echo "<tr><td bgcolor=\"darkgreen\"><img src=\"img/clearpixel.png\" ";
   echo "width=\"1\" height=\"2\" alt=\"leer\" /></td></tr>\n";

   /* die einzelnen Zeiten ausgeben */
   while ($start < $ende)
   {
     /*
      * Eine Tabellenzeile noch ausgeben um Termine raeumlich trennen zu
      * koennen.
      */
     echo "<tr><td height=\"1\"></td></tr>\n";

     /* jede volle Stunde weiss kennzeichnen */
     if ($start % 3600) $weiss = ""; else $weiss = "color:#FFFFFF";

     echo "<tr><td height=\"13\" style=\"font-size:7pt;text-align:center;";
     printf("%s\">%s</td></tr>\n", $weiss, date("H:i", $start));

     $start += 900;
   }

   printf("</table>\n");
 }

 /*
  * Eine Zelle wird ausgegeben die die gewuenschte Farbe enhaelt.
  */
 function kal_zelle_farbe($farbe, $breite = 1)
 {
   printf("<td bgcolor=\"%s\"><img src=\"img/clearpixel.png\" ", $farbe);
   printf("width=\"%s\" height=\"13\" alt=\"leer\" /></td>\n", $breite);
 }

 /*
  * Ermittelt die Hintergrundfarbe fuer die angegebenen Argumente fuer den
  * Standardhintergrund.
  */
 function kal_hintergrundfarbe_standard($feiertag, $fehltag, $fehltagnichtgenehmigt=false, $vargangenheit=false)
 {
   if (strlen($feiertag) > 0)
   {
     $bg_color = "#999999";
   }
   else if (strlen($fehltag) > 0)
   {
	 if(!$fehltagnichtgenehmigt) $bg_color = "#666666";
	 elseif($vargangenheit) $bg_color = "#996666";
	 else $bg_color = "#CCCCCC";
   }
   else
   {
     $bg_color = "#191919";
   }

   return $bg_color;
 }

 /*
  * Ermittelt die Hintergrundfarbe fuer die erste Spalte die als grafischer
  * Balken gezeigt wird.
  */
 function kal_hintergrund_eins($zk_color, $ta_color)
 {
   if (strlen($zk_color) > 0)
   {
     $bg_color = $zk_color;
   }
   elseif (strlen($ta_color) > 0)
   {
     $bg_color = $ta_color;
   }
   else
   {
     $bg_color = "#darkgreen";
   }

   return $bg_color;
 }

 /*
  * Eine Tabelle ausgeben die einen ganzen Tag darstellt. Insgesamt besteht jede
  * Zeile aus 14 Spalten.
  *
  * $kalender - die einzelnen Termine
  * $ma       - MitarbeiterID
  * $start    - Startzeit fuer diesen Tag
  *
  * $kal_von  - Kalenderstartzeit
  * $kal_bis  - Kalenderendzeit
  *
  * $width - zulaessige Breite fuer einen Tag
  * $feier - wenn nicht leer dann ein Feiertag
  * $fehl_name - wenn nicht leer ein Fehlzeit
  * $fehl_farbe - Fehlzeitfarbe
  */
 function kal_tabelle_tag($kalender, $ma, $start, $kal_von, $kal_bis, $width, $feier, $fehl_name,
                          $fehl_farbe, $fehl_nicht_genehmigt=false, $tagesansicht=false, $meldungBeiArbeitszeitfehler=false)
 {
   /* Reihenfolge der Spaltenbelegung festlegen - 14 Spalten moeglich */
   if($tagesansicht) $reihenfolge=array("0","3","6","9","12","15","18","21","24","27","30","33","36","39");
   else $reihenfolge=array("0","13","12","11","10","9","8","7","6","5","4","3","2","1");

   /* Startzeit und Endzeit fuer diesen Tag */
   $t1 = mktime($kal_von, 0, 0, date("n", $start), date("j", $start),
                date("Y", $start));

   $t2 = mktime($kal_bis, 0, 0, date("n", $start), date("j", $start),
                date("Y", $start));

   /*
    * Jetzt die einzelnen Termine durchgehen und fuer den einzelnen Tag
    * ein Ausgabearray zusammenstellen. Dieses wird dann ausgegeben.
    */
   $pos = 1;
   $zk_von = $zk_bis = $zk_arbeitszeit = $zk_pause = 0;
   $amStk = false;
   foreach ($kalender as $termin)
   {
	 /* Infoausgabe braucht Variable fuer Anzahl schon ausgegebene Zeichen */
     $termin["info_pos"] = 0;

     /* welche Zeileinfo schon ausgegeben wurde */
     $termin["zeile_info"] = 0;

	 /* Zeitkarten: nicht mehr als 10h, Pausen... */
	 if($termin['art'] == 'z' && $termin["ts2"] > $start && $termin["ts1"] < ($start+86400)) {
		if($termin["ts1"] > $zk_bis) {
			if($zk_bis > 0) $zk_pause += $termin["ts1"] - $zk_bis;
			if($zk_bis - $zk_von > 21600) $amStk = true;
			$zk_arbeitszeit += $zk_bis - $zk_von;
			$zk_von = $termin["ts1"];
		}
		if($termin["ts2"] > $zk_bis) {
			$zk_bis = $termin["ts2"];
		}
	 }

     /*
      * Die Startzeit oder die Endzeit kann innerhalb der grafischen Ansicht
      * liegen. Deshalb pruefen ob gezeigt wird.
      */
     $startzeile = -1;

     if ($termin["ts1"] >= $t1 && $termin["ts1"] <= $t2)
     {
       /* Startzeit liegt im grafischen Bereich */
       $startzeile = $termin["ts1"] - $t1;
     }

     if (($termin["ts2"] >= $t1 && $termin["ts2"] <= $t2 &&
          $startzeile < 0) || $termin["ts1"] < $t1 && $termin["ts2"] > $t2)
     {
       /* Endzeit liegt im grafischen Bereich und Startzeit davor */
       $startzeile = 0;
     }

     /* nur wenn eine gueltige Startzeile ermittelt werden konnte */
     if ($startzeile >= 0)
     {
       /* Zeilennummer fuer Ausgabe */
       $zeile = $startzeile/900;

       /* Ausgabespalte bestimmen */
       $raus = 0; $spalte = 0;
       do
       {
         if (empty($termine[$zeile][$reihenfolge[$spalte]])) $raus = 1;

         ++$spalte;
       } while ($raus == 0 && $spalte < 14);

       /*
        * Eine Spalte noch abziehen weil Schleife vorher immer eins
        * addiert bevor sie beendet wird.
        */
       --$spalte;

       /* alle Zeilen belegen */
       for ($i = $startzeile/900; $i < ($termin["ts2"] - $t1)/900; $i++)
       {
         $termine[$i][$reihenfolge[$spalte]] = $pos;
       }
     }
     ++$pos;
   }
   $zk_arbeitszeit += $zk_bis - $zk_von;
   if($zk_bis - $zk_von > 21600) $amStk = true;

   /* diesen Tag in einer Tabelle kapseln */
   printf("<table width=\"%s\" border=\"0\" cellspacing=\"0\" ", $width);
   printf("cellpadding=\"0\">\n");

   /*
    * Wochentag mit Datum zentriert ausgeben - Link auf Tagtermine. Falls
    * dies ein Feiertag ist, den Hintergrund dementsprechend setzen. Zusaetzlich
    * werden auch Fehltage mit einer anderen Hintergrundfarbe dargestellt.
    */
   $style = "text-align:center";

   if (strlen($feier) > 0)
   {
     $style .= ";background-color:#999999";
   }
   elseif(strftime("%w", $start)==0 || strftime("%w", $start)==6)
   {
     $style .= ";background-color:#660000";
   }
   else if (strlen($fehl_name) > 0)
   {
     if($fehl_nicht_genehmigt) {
		 if(time() > $t1) $style .= ";background-color:#996666";
		 else $style .= ";background-color:#CCCCCC";
	 }else $style .= ";background-color:#666666";
   }

   printf("<tr><td width=\"10\" style=\"%s\">", $style);
   printf("</td><td colspan=\"12\" style=\"%s\">", $style);

   if($tagesansicht) {
		echo "<a href=\"".$_SERVER['PHP_SELF']."?anz=tg&amp;tag=".date("Y-m-d", $start-80000);
		if(isset($_GET['proj_id'])) echo "&amp;proj_id=".$_GET['proj_id'];
		echo "&amp;ma=$ma\">";
		echo "<img src=\"img/zurueck.png\" height=\"12\" width=\"12\"/></a> ";
		echo "<a href=\"".$_SERVER['PHP_SELF']."?anz=tg&amp;tag=".date("Y-m-d", $start);
		if(isset($_GET['proj_id'])) echo "&amp;proj_id=".$_GET['proj_id'];
		echo "&amp;ma=$ma\"";
   } else {
		echo "<a href=\"".$_SERVER['PHP_SELF']."?anz=tg&amp;tag=".date("Y-m-d", $start);
		if(isset($_GET['proj_id'])) echo "&amp;proj_id=".$_GET['proj_id'];
		echo "&amp;ma=$ma\"";
   }
   if($meldungBeiArbeitszeitfehler) {
	   /* Arbeitszeit: mehr als 12h? Pausen? */
	   if($zk_arbeitszeit > 43200) {
			$warning_arbeitszeit = "Arbeitszeit von mehr als 12 Stunden";
	   } elseif($amStk) {
			$warning_arbeitszeit = "Arbeitszeit von mehr als 6:00h am St&uuml;ck";
	   } elseif($zk_arbeitszeit > 32400 && $zk_pause < 2700) {
			$warning_arbeitszeit = "Ab 9:00h Arbeitszeit sind 45min Pause einzuhalten";
	   } elseif($zk_arbeitszeit > 21600 && $zk_pause < 900) {
			$warning_arbeitszeit = "Ab 6:00h Arbeitszeit sind 15min Pause einzuhalten";
	   } else $warning_arbeitszeit = '';
   } else $warning_arbeitszeit = '';

   if (strlen($warning_arbeitszeit) > 0) {
     printf("\" id=\"tag$start\" style=\"color:#FF0000\" title=\"%s", $warning_arbeitszeit);
   } elseif (strlen($feier) > 0) {
     printf("\" style=\"color:#333333\" title=\"%s", $feier);
   } else if (strlen($fehl_name) > 0) {
     if (strlen($fehl_farbe) > 0) $color = $fehl_farbe; else $color = "#333333";
     echo "\" style=\"color:$color\"" . stwToolTip($fehl_nicht_genehmigt ? "$fehl_name - nicht genehmigt" : $fehl_name);
   }

   printf("\">%s</a>", strftime("%a, %d.%m.%Y", $start));
   if (strlen($warning_arbeitszeit) > 0) {
		echo "<script type=\"text/javascript\"><!--\n";
		echo "Tip('<b style=\"width:200px;white-space:normal;\">$warning_arbeitszeit!</b>', BGCOLOR, '#CCCCCC', OPACITY, '90', CLOSEBTN, 1, TITLE, 'Elektronischer Verwaltungsleiter',TITLEBGCOLOR, '#006600', WIDTH, 205, HEIGHT, 30, FIX, ['tag$start',-50,0], TITLEALIGN, 'center', TITLEFONTSIZE, '10px', STICKY, 1);\n";
		echo "--></script>\n";
   }
   if($tagesansicht) {
		echo "&nbsp;<a href=\"".$_SERVER['PHP_SELF']."?anz=tg&amp;tag=".date("Y-m-d", $start+100000);
		if(isset($_GET['proj_id'])) echo "&amp;proj_id=".$_GET['proj_id'];
		echo "&amp;ma=$ma\">";
		echo "<img src=\"img/vor.png\" height=\"12\" width=\"12\"/></a>";
   }
   printf("</td><td width=\"10\" style=\"%s\"></td></tr>\n", $style);

   /* waagerechte gruene Trennlinie zwischen Datum und Terminen */
   printf("<tr><td colspan=\"14\" bgcolor=\"#008000\"><img src=\"img");
   echo "/clearpixel.png\" width=\"1\" height=\"2\" alt=\"leer\">";

   echo "</td></tr>\n";

   // sicherstellen das Variable initialisiert ist
   if (!isset($termine)) $termine = NULL;

   /* Das ganze Array durchgehen und die Ausgabe dementsprechend machen. */
   $i = 0;
   do
   {
     printf("<tr>\n");

     $j = 0;
     $einmal = 0;

     do
     {
       /*
        * Eine raeumliche Trennung zwischen den Terminen erstellen. Dazu wird
        * noch eine zusaetzliche Tabellenzeile eingefuegt. Hier muss erkannt
        * werden ob als naechstes ein neuer Termin folgt.
        */
       if ($einmal == 0)
       {
         if (count($termine[$i]) == 0)
         {
           /* kein Termin vorhanden - normale Hintergrundfarbe */
           printf("<td height=\"1\" colspan=\"14\" style=\"background-color:");
           printf("%s\">", kal_hintergrundfarbe_standard($feier, $fehl_name, $fehl_nicht_genehmigt, (time() > $t1)));
         }
         else
         {
           $pos = $termine[$i][0] - 1;

           if($tagesansicht) $hintergrund='white';
		   /* bei Empfangsdienst Hintergrund ein wenig blauer :) */
           elseif($kalender[$pos]["empfang"]==1) $hintergrund = "#232346";
           elseif($kalender[$pos]["beendet"] > 0 && $kalender[$pos]["beendet"]+86400 < $kalender[$pos]['ts1']) $hintergrund = "#666666";
		   else $hintergrund = "#232323";

           /* pruefen ob ein neuer Termin anfaengt */
           if ($kalender[$pos]["zeile_info"] == 0 &&
               !empty($termine[$i][0]))
           {
             /* neuer Termin - normale Hintergrundfarbe */
             for($J=0;$J<14;$J++) {
               if(empty($termine[$i][$J])) echo "<td style=\"background-color:".kal_hintergrundfarbe_standard($feier, $fehl_name, $fehl_nicht_genehmigt, (time() > $t1))."\" height=\"1\">";
               else {
                 $temppos = $termine[$i][$J] - 1;
                 $bg_color = kal_hintergrund_eins($kalender[$temppos]["ta_color_zk"],$kalender[$temppos]["ta_color"]);
                 echo "<td style=\"background-color:$bg_color\" height=\"1\">";
                 if($tagesansicht) {
                   echo "<td height=\"1\" style=\"background-color:$hintergrund\">";
                   $J++;
                 }
               }
             }
           }
           elseif($tagesansicht)
		   {
		     for($pos = 0; $pos < 40; $pos+=3)
               $J = $pos / 3;
			   if (!empty($termine[$i][$J])) {
                 $bg_color = kal_hintergrund_eins($kalender[$pos]["ta_color_zk"],$kalender[$pos]["ta_color"]);
                 echo "<td height=\"1\" style=\"background-color:$bg_color\"></td>";
                 echo "<td height=\"1\" style=\"background-color:$hintergrund\">";
                 echo "<td height=\"1\" style=\"background-color:#191919\">";
			   }
			 
		   }
		   else
           {
             /* nur ein Termin in erster Spalte vorhanden */
             if (count($termine[$i]) == 1 && !empty($termine[$i][0]))
             {
               $bg_color = kal_hintergrund_eins($kalender[$pos]["ta_color_zk"],
                                                $kalender[$pos]["ta_color"]);

               /* vorderen Bereich zeichnen */
               printf("<td height=\"1\" style=\"background-");
               printf("color:%s\"></td>", $bg_color);

               /* jetzt folgt die naechste Spalte */
               printf("<td height=\"1\" colspan=\"13\" style=");
               printf("\"background-color:$hintergrund\">");

               $einmal = 1;
             }

             /*
              * Zwei Termine in erster und dreizehnter Spalte vorhanden.
              */
             if (count($termine[$i]) == 2 && !empty($termine[$i][0]) &&
                 !empty($termine[$i][13]))
             {
               $bg_color = kal_hintergrund_eins($kalender[$pos]["ta_color_zk"],
                                                $kalender[$pos]["ta_color"]);

               /* vorderen Bereich zeichnen */
               printf("<td height=\"1\" style=\"background-");
               printf("color:%s\"></td>", $bg_color);

               printf("<td height=\"1\" colspan=\"12\" style=");
               printf("\"background-color:$hintergrund\"></td>");

               /* Farbe fuer die 13. Spalte bestimmen. */
               $pos = $termine[$i][13] - 1;
               $bg_color = kal_hintergrund_eins($kalender[$pos]["ta_color_zk"],
                                                $kalender[$pos]["ta_color"]);

               printf("<td height=\"1\" style=\"background-");
               printf("color:%s\">", $bg_color);

               $einmal = 1;
             }

             /*
              * Drei Termine in erster, dreizehnter und zwlfter Spalte
              * vorhanden.
              */
             if (count($termine[$i]) == 3 && !empty($termine[$i][0]) &&
                 !empty($termine[$i][13]) && !empty($termine[$i][12]))
             {
               $bg_color = kal_hintergrund_eins($kalender[$pos]["ta_color_zk"],
                                                $kalender[$pos]["ta_color"]);

               /* vorderen Bereich zeichnen */
               printf("<td height=\"1\" style=\"background-");
               printf("color:%s\"></td>", $bg_color);

               printf("<td heigth=\"1\" colspan=\"11\" style=");
               printf("\"background-color:$hintergrund\"></td>");

               /* Farbe fuer die 12. Spalte bestimmen. */
               $pos = $termine[$i][12] - 1;
               $bg_color = kal_hintergrund_eins($kalender[$pos]["ta_color_zk"],
                                                $kalender[$pos]["ta_color"]);

               printf("<td height=\"1\" style=\"background-");
               printf("color:%s\"></td>", $bg_color);

               /* Farbe fuer die 13. Spalte bestimmen. */
               $pos = $termine[$i][13] - 1;
               $bg_color = kal_hintergrund_eins($kalender[$pos]["ta_color_zk"],
                                                $kalender[$pos]["ta_color"]);

               printf("<td height=\"1\" style=\"background-");
               printf("color:%s\">", $bg_color);

               $einmal = 1;
             }

             /*
              * Wenn bis jetzt die Variable $einmal nicht belegt ist, wurde
              * noch nichts ausgegeben. Deshalb 14 Tabellenspalten ausgeben.
              */
             if ($einmal == 0)
             {
               for ($ch = 0; $ch < 14; $ch++)
               {
                 if ($ch > 0) printf("</td>");

                 if (empty($termine[$i][$ch]))
                 {
                   $bg_color = "#191919";
                 }
                 else
                 {
                   $pos = $termine[$i][$ch] - 1;
                   $bg_color = kal_hintergrund_eins(
                   $kalender[$pos]["ta_color_zk"], $kalender[$pos]["ta_color"]);
                 }

                 printf("<td height=\"1\" style=\"background-");
                 printf("color:%s\">", $bg_color);
               }
             }
           }
         }

         printf("</td></tr>\n<tr>");

         /* nur einmal ausfuehren pro Tabellenzeile */
         $einmal = 1;
       }

       if (!empty($termine[$i][$j]))
       {
         $pos = $termine[$i][$j] - 1;

         /* Farbe fuer den Hintergrund festlegen */
		 $bg_color = kal_hintergrund_eins($kalender[$pos]["ta_color_zk"], $kalender[$pos]["ta_color"]);
         /*
          * Entweder nur den normalen Titel fuer den Link ausgeben oder
          * alle zusaetzlichen Informationen die auch daneben stehen. Dies
          * ist nur notwendig wenn es nicht der erste Termin (Spalte 0) ist.
          */
         $twentyfive = $tagesansicht ? 60 : 25;
		 if ($j == 0)
         {
           $titel = $kalender[$pos]["ta_title"];
         }
         else
         {
           $titel  = $kalender[$pos]['cont_title_tt'];
           $titel .= $kalender[$pos]["ta_title"] . " ";
           $titel .= $kalender[$pos]["ta_text"]." ";

           $titel .= $kalender[$pos]["von"]." - ";
           $titel .= $kalender[$pos]["bis"];

           if ($kalender[$pos]["datum_link"] == 1)
           {
             $titel .= " ".$kalender[$pos]["cont_title"];
           }
         }

         /* Spalte ausgeben */
         printf("<td style=\"background-color:%s\" height=\"13\"", $bg_color);
         printf(" width=\"10\">\n");

         if ($kalender[$pos]["datum_link"] == 1)
         {
           if ($pos == $termine[$i + 1][$j] - 1)
           {
             printf("<a href=\"%s\">", $kalender[$pos]["datum_url"]);
             printf("<img src=\"img/clearpixel.png\" width=\"10\" ");
             printf("height=\"13\" border=\"0\" %s></a>\n", stwToolTip(trim($titel)));
           }
           else
           {
             if (!empty($kalender[$pos]["del_url"]) &&
                  $kalender[$pos]["del_link"] >= 1)
             {
               if($kalender[$pos]["del_link"] > 4) printf("<a href=\"%s\" ", str_replace('&loc=kal','',$kalender[$pos]["del_url"]));
			   else printf("<a href=\"%s\" ", $kalender[$pos]["del_url"]);
               if($kalender[$pos]["del_link"] < 4) printf("onclick=\"return stwConfirm('%s',%s", $kalender[$pos]["del_url"],($kalender[$pos]["del_link"]<2 ? 0 : 1));
               if($kalender[$pos]["del_link"])
			   printf(")\"><img src=\"img/del_kal.png\" width=\"10\" ");
               printf("height=\"13\" border\"0\" ");
               printf("%s></a>", stwToolTip("<b>VORSICHT!</b> L&ouml;schen!"));
             }
             else
             {
               printf("<a href=\"%s\">", $kalender[$pos]["datum_url"]);
               printf("<img src=\"img/clearpixel.png\" width=\"10\" ");

               printf("height=\"13\" border=\"0\" ");
               printf("%s></a>\n", stwToolTip(trim($titel)));
             }
           }
         }
         else
         {
           /* Ausgabe von Information ber Raumnutzung (wer, wozu...) */
           printf("<img src=\"img/clearpixel.png\" width=\"10\" ");
           printf("height=\"13\" border=\"0\" %s>", stwToolTip(trim($kalender[$pos]['cont_title_tt'])));
         }

         printf("</td>\n");

         /*
          * Zusaetzliche Informationen zu einem Termin werden in einer
          * weiteren Spalte ausgegeben wenn noch Platz dafuer vorhanden ist.
          */
         $span = 0; $modus = 0;

         /* nur ein Termin in erster Spalte vorhanden */
         if (count($termine[$i]) == 1 && !empty($termine[$i][0]))
         {
           $span = 13;
         }

         /*
          * Zwei Termine in erster und dreizehnter Spalte vorhanden.
          */
         if (count($termine[$i]) == 2 && !empty($termine[$i][0]) &&
             !empty($termine[$i][13]) && $j == 0)
         {
           $span = 12;
         }

         /*
          * Drei Termine in erster, dreizehnter und zwlfter Spalte vorhanden.
          */
         if (count($termine[$i]) == 3 && !empty($termine[$i][0]) &&
             !empty($termine[$i][13]) && !empty($termine[$i][12]) && $j == 0)
         {
           $span = 11;
         }

		 if($tagesansicht) {
			$span = 1;
		 }

         /* zusaetzliche Spalte ausgeben */
         if ($span > 0 || $tagesansicht)
         {
           /*
            * Textfarbe normal ist weiss aber fuer Zusatzinfos wie die
            * Menuefarbe.
            */
           if ($kalender[$pos]["zeile_info"] < 2)
           {
             $font_color = $tagesansicht ? '000000' : "FFFFFF";
           }
           else
           {
             $font_color = "666666";
           }

           $width = $tagesansicht ? "width:300px;" : '';
		   printf("<td style=\"font-size:7pt;$width background-color:$hintergrund;");
           printf("color:#%s\" colspan=\"%s\" ", $font_color, $span);

           if(!$tagesansicht) {
		     if (strlen($kalender[$pos]['cont_title_tt']) > 0){
           	   echo stwToolTip(trim($kalender[$pos]['cont_title_tt']));
             } elseif (strlen($kalender[$pos]['cont_title']) > 0){
           	   echo stwToolTip(trim($kalender[$pos]['cont_title']));
			 }
           }

           printf(">\n");

           /* Text anklickbar machen wenn freigeschalten */
           if ($kalender[$pos]["datum_link"] == 1)
           {
             printf("<a href=\"%s\" style=\"", $kalender[$pos]["datum_url"]);
             printf("font-size:7pt;background-color:$hintergrund;color:#");
             printf("%s;font-style:normal;font-weight:normal\">", $font_color);
           }

           /* ab hier werden Texte in der grafischen Ansicht ausgegeben */
           if ($kalender[$pos]["zeile_info"] == 0)
           {
             /* Info ueber Projekt ausgeben */
			 echo "&nbsp;<b";
			 if ($tagesansicht && strlen($kalender[$pos]['cont_title_tt']) > 0){
           	   echo stwToolTip(trim($kalender[$pos]['cont_title_tt']));
             } elseif ($tagesansicht && strlen($kalender[$pos]['cont_title']) > 0){
           	   echo stwToolTip(trim($kalender[$pos]['cont_title']));
			 }
             printf(">%s</b>&nbsp;", $kalender[$pos]["ta_text"]);
			 if($tagesansicht) {
				echo "&nbsp;".$kalender[$pos]["von"]."&nbsp;-&nbsp;".$kalender[$pos]["bis"];
				$kalender[$pos]["zeile_info"] ++;
             }
			 $modus = 1;
           }

           /* Terminzeiten ausgeben wenn dran */
           elseif ($kalender[$pos]["zeile_info"] == 1)
           {
             /* wenn der Termin den ganzen Tag geht - keine Zeit zeigen */
             if (!($kalender[$pos]["ts1"] < $t1 &&
                   $kalender[$pos]["ts2"] > $t2))
             {
               /* nur Startzeit zeigen wenn Start an diesem Tag */
               if ($kalender[$pos]["ts1"] > mktime(0, 0, 0, date("n", $t1),
                                                   date("j", $t1),
                                                   date("Y", $t1)))
               {
                 printf("&nbsp;%s", $kalender[$pos]["von2"] ? $kalender[$pos]["von2"] : $kalender[$pos]["von"]);
                 $start_vorhanden = 1;
               }
               else
               {
                 $start_vorhanden = 0;
               }

               /* nur Endzeit zeigen wenn Ende an diesem Tag */
               if ($kalender[$pos]["ts2"] < mktime(0, 0, 0, date("n", $t2),
                                                   date("j", $t2) + 1,
                                                   date("Y", $t2)))
               {
                 if ($start_vorhanden == 1)
                 {
                   printf("&nbsp;-");
                 }
                 else
                 {
                   printf("&nbsp;bis");
                 }

                 printf("&nbsp;%s&nbsp;", $kalender[$pos]["bis2"] ? $kalender[$pos]["bis2"] : $kalender[$pos]["bis"]);
               }
             }
             else
             {
               printf("&nbsp;ganztags&nbsp;");
             }

             /* jetzt wird auf Kurzinfomodus umgeschaltet */
             $modus = 1;
           }

           /*
            * Langinfo ausgeben wenn dran. Wenn es eine ZK ist und
            * abrechnungsrelevant geschaltet -> den ganzen Text nicht zeigen.
            */
           if ($kalender[$pos]["zeile_info"] == 2 &&
               $kalender[$pos]["ta_title"] != "abrechnungsrelevant" &&
               $kalender[$pos]["ta_title"] != "abgerechnet" &&
               $kalender[$pos]["ta_title"] != "abgelegt")
           {
			 if(strlen(substr($kalender[$pos]["cont_title"],$kalender[$pos]["info_pos"], $twentyfive)) == 0) {
			   $kalender[$pos]["info_pos"] = 0;
			   $kalender[$pos]["zeile_info"] ++;
			 } else {
               printf("&nbsp;%s", substr($kalender[$pos]["cont_title"],
                       $kalender[$pos]["info_pos"], $twentyfive));
			   $kalender[$pos]["info_pos"] += $twentyfive;
             }
		   }

           /* Text anklickbar machen wenn freigeschalten */
           if ($kalender[$pos]["datum_link"] == 1) printf("</a>\n");

           /* bei LOM-Terminen (Tagesansicht) noch weitere Informationen ausgeben */
		   if ($kalender[$pos]["lom"] === true && $kalender[$pos]["zeile_info"] == 6) {
			 if(strlen(substr($kalender[$pos]["notiz"],$kalender[$pos]["info_pos"], $twentyfive)) == 0) {
			   $kalender[$pos]["info_pos"] = 0;
			   $kalender[$pos]["zeile_info"] ++;
			 } else {
               printf("&nbsp;%s", substr($kalender[$pos]["notiz"],$kalender[$pos]["info_pos"], $twentyfive));
			   $kalender[$pos]["info_pos"] += $twentyfive;
			 }
		   } elseif ($kalender[$pos]["lom"] === true && $kalender[$pos]["zeile_info"] > 2) {
		     if($kalender[$pos]["info_pos"] != 0) {
			   if($kalender[$pos]["zeile_info"] == 4) {
				 if(strlen(substr($teilnehmer[$pos],$kalender[$pos]["info_pos"], $twentyfive)) == 0) {
				   $kalender[$pos]["info_pos"] = 0;
				   $kalender[$pos]["zeile_info"] ++;
				 } else {
					if(strlen(substr($teilnehmer[$pos], $kalender[$pos]["info_pos"])) > $twentyfive) {
						$strripos = strripos(substr($teilnehmer[$pos], $kalender[$pos]["info_pos"], $twentyfive),', ') + 2;
						echo '&nbsp;'.substr($teilnehmer[$pos], $kalender[$pos]["info_pos"], $strripos);
						$kalender[$pos]["info_pos"] += $strripos;
					} else {
						echo '&nbsp;'.substr($teilnehmer[$pos], $kalender[$pos]["info_pos"]);
						$kalender[$pos]["info_pos"] += $twentyfive;
					}
				 }
			   } elseif($kalender[$pos]["zeile_info"] == 5) {
			     if(empty($kalender[$pos]["aufgaben"][$kalender[$pos]["info_pos"]])) {
				   $kalender[$pos]["info_pos"] = 0;
				   $kalender[$pos]["zeile_info"] ++;
				 } else {
				   $aufg = abfrage("select a.aufgabe_id, a.nr, p.prioritaet, a.titel, a.text, date_format(a.termin, '%d.%m.%Y'), a.erledigt 
									from tb_aufgaben a left join tb_prio p using(prio)
									where a.aufgabe_id = '".$kalender[$pos]["aufgaben"][$kalender[$pos]["info_pos"]]."'");
				   $tt = "<b>$aufg[1]: $aufg[3]</b><br><b>Priorit&auml;t:</b> $aufg[2] <b>Termin:</b> $aufg[5] <b>erledigt:</b> $aufg[6]%<br>$aufg[4]";
				   echo "<a href=\"auf_and.php?aufgabe_id=$aufg[0]\" style=\"color:#666666;font-weight:normal;\"".stwToolTip($tt,1,80).">";
				   echo "&nbsp;".substr("$aufg[1] ($aufg[2]): $aufg[3]",0,$twentyfive);
				   echo "</span>";
			       $kalender[$pos]["info_pos"] ++;
				 }
			   }
			 } 
			 if($kalender[$pos]["info_pos"] == 0) {
			   if($kalender[$pos]["zeile_info"] == 3) {
			     if($kalender[$pos]["anleiter"][0]) {
					global $AppCode;
					if($_SESSION[$AppCode]["ULV"] > 5) {
						$anl = implode(",", $kalender[$pos]["anleiter"]);
						$anlzks = abfrage1("select inhalte2, pers_id, date_format(t.von, '%H:%i'), 
											date_format(t.bis, '%H:%i') from tb_ab_zk z
											left join tb_projekte p using(proj_id)
											left join tb_hilfeart h using(hilfeart_id)
											left join tb_termine t using(termin_id)
											where z.ab='j'
											and unix_timestamp(t.von) < '{$kalender[$pos]["ts2"]}'
											and unix_timestamp(t.bis) > '{$kalender[$pos]["ts1"]}'
											and h.hilfeart in ('TTP','TTS','TTH','TTV')
											and pers_id in ($anl)");
						$tt = '';
						while($zk = mysql_fetch_row($anlzks)) {
							if($tt != '') $tt .= '<br />';
							$tt .= "<b>" . pers_kname($zk[1]) . " </b>$zk[2] - $zk[3]: ";
							$tt .= (empty($zk[0])) ? '<b>??? KEIN PRAKTISCHER ARBEITSERFOLG ???</b>' : $zk[0];
						}
						if($tt != '') $tt = stwToolTip($tt,true,120);
					} else $tt = '';
					echo "<b $tt style=\"color:black\">&nbsp;Anleiter:</b>";
					foreach($kalender[$pos]["anleiter"] as $anleiter) {
						if($kalender[$pos]["info_pos"] > 1) echo ",";
						if($kalender[$pos]["info_pos"] > 0) {
							echo "&nbsp;";
							if($anleiter == $kalender[$pos]["anleiter"][0]) echo "<u>";
							echo pers_kname($anleiter);
							if($anleiter == $kalender[$pos]["anleiter"][0]) echo "</u>";
						}
						$kalender[$pos]["info_pos"]++;
					}
					$kalender[$pos]["info_pos"] = 0;
					$kalender[$pos]["zeile_info"] ++;
				 } else $kalender[$pos]["zeile_info"] ++;
			   } elseif($kalender[$pos]["zeile_info"] == 4) {
			     if($kalender[$pos]["teilnehmer"][0] === true) {
					global $AppCode;
					if($_SESSION[$AppCode]["ULV"] > 5) {
						$tns = implode(",", $kalender[$pos]["teilnehmer"]);
						$tnzks = abfrage1("select inhalte, pers_id, date_format(t.von, '%H:%i'), 
											date_format(t.bis, '%H:%i') from tb_ab_zk z
											left join tb_termine t using(termin_id)
											where z.ab='j'
											and unix_timestamp(t.von) < '{$kalender[$pos]["ts2"]}'
											and unix_timestamp(t.bis) > '{$kalender[$pos]["ts1"]}'
											and pers_id in ($tns)");
						$tt = '';
						while($zk = mysql_fetch_row($tnzks)) {
							if($tt != '') $tt .= '<br />';
							$tt .= "<b>" . pers_name($zk[1]) . " </b>$zk[2] - $zk[3]: ";
							$tt .= (empty($zk[0])) ? '<b>??? KEIN PRAKTISCHER ARBEITSERFOLG ???</b>' : $zk[0];
						}
						if($tt != '') $tt = stwToolTip($tt,true,100);
					} else $tt = '';
					echo "<b $tt style=\"color:black\">&nbsp;Teilnehmer: </b>";
					$teilnehmer[$pos] = ' Teilnehmer: ';
					foreach($kalender[$pos]["teilnehmer"] as $tn) {
						if($teilnehmer[$pos] != ' Teilnehmer: ') $teilnehmer[$pos].=', ';
						if($kalender[$pos]["info_pos"] > 0) $teilnehmer[$pos] .= pers_name($tn);
						$kalender[$pos]["info_pos"]++;
					}
					if(strlen($teilnehmer[$pos]) > $twentyfive) {
						$strripos = strripos(substr($teilnehmer[$pos], 13, $twentyfive-10),', ');
						echo substr($teilnehmer[$pos], 13, $strripos+2);
						$kalender[$pos]["info_pos"] = $strripos+15;
					} else {
						$kalender[$pos]["info_pos"] = 0;
						$kalender[$pos]["zeile_info"] ++;
						echo substr($teilnehmer[$pos], 13);
					}
				 } else $kalender[$pos]["zeile_info"] ++;
			   } elseif($kalender[$pos]["zeile_info"] == 5) {
			     if($kalender[$pos]["aufgaben"][0] === true) {
					echo "<b style=\"color:".($tagesansicht ? 'black' : 'white')."\">&nbsp;Aufgaben</b>";
					$kalender[$pos]["info_pos"] ++;
				 } elseif($kalender[$pos]["aufgaben"][0] === false) {
					if($tagesansicht) echo "&nbsp; &nbsp; &nbsp; ";
					echo " <b style=\"color:red;\">??? KEINE AUFGABEN ???</b>";
					$kalender[$pos]["info_pos"] ++;
				 } else $kalender[$pos]["zeile_info"] ++;
			   }
			 }
		   }

		   printf("</td>\n");
           $j += $span;

           /* wenn Modus auf 1 gesetzt ist soll die naechste Infozeile folgen */
           if ($modus == 1)
           {
             $kalender[$pos]["zeile_info"] += 1;
             $kalender[$pos]["info_pos"]    = 0;
           }
         }
       }
       else
       {
         $title = "";

         /* normale Hintergrundfarbe oder Feiertag */
         if (strlen($feier) > 0)
         {
           $bg_color = "#999999";
         }
         else if (strlen($fehl_name) > 0)
         {
           $title = "title=\"".$fehl_name;
		   if($fehl_nicht_genehmigt) {
			 $title .= ' - nicht genehmigt!';
			 if(time() > $t1) $bg_color = "#996666";
			 else $bg_color = "#CCCCCC";
		   }else $bg_color = "#666666";
		   $title .= "\"";
         }
         else
         {
           $bg_color = "#191919";
         }

         /*
          * Um die Darstellung zu beschleunigen - pruefen ob die ganze Zeile
          * leer ist. Falls dies der Fall ist gleich die ganze Zeile ausgeben.
          */
         if (count($termine[$i]) == 0) $span = 14; else $span = 1;

         printf("<td style=\"font-size:7pt;background-color:%s\"", $bg_color);
         printf(" height=\"13\" width=\"10\" colspan=\"%s\">\n", $span);

         /* Bild noch einfuegen fuer gleichmaessige Hoehe */
         printf("<img src=\"img/clearpixel.png\" width=\"10\" ");
         printf("height=\"13\" border=\"0\" %s></td>\n", $title);

         if ($span > 1) $j += $span;
       }

       ++$j;

     } while ($j < 14);

     printf("</tr>\n");

     ++$i;

   } while ($i < ($t2 - $t1)/900);

   /* Tag ausgegeben - alles loeschen */
   unset($termine);

   /* Tag abschliessen und damit die Tabelle beenden */
   printf("</table>\n");
 }

$persid = empty($_GET['ma']) ? $_SESSION[$AppCode]['UID'] : $_GET['ma'];
echo "<input type=\"hidden\" id=\"btn1action\" value=\"\" />\n";
echo "<input type=\"hidden\" id=\"btn2action\" value=\"\" />\n";
echo "<table id=\"stwDialog\" cellspacing=\"0\" style=\"display:none;position:absolute;background-color:#CCCCCC;width:400px;top:50%;left:50%;margin-top:-75px;margin-left:-200px;\">";
echo "<tr><th colspan=\"2\" style=\"padding-left:10px;background-color:white;color:black;width:100%;\">Sicherheitsabfrage</th>";
echo "<td style=\"background-color:red\"><a onclick=\"document.getElementById('stwDialog').style.display='none';return false;\" href=\"#\">&nbsp;X&nbsp;</a></td></tr>\n";
echo "<tr><td class=\"ww\" colspan=\"3\" style=\"color:black;text-align:center;vertical-align:middle;height:80px\">Soll der gesamte Termin gel&ouml;scht werden<br>oder wollen Sie lediglich ".pers_kname($persid)."<br>aus der Teilnehmerliste entfernen?</td></tr>\n";
echo "<tr><td style=\"text-align:center;height:40px;width:50%\"><input style=\"width:150px\" type=\"button\" onClick=\"self.location.href=document.getElementById('btn1action').value\" id=\"btn1\" value=\"Termin l&ouml;schen\" /></td>";
echo "<td style=\"text-align:center\"><input style=\"position:relative;left:20px;width:150px\" type=\"button\" onClick=\"self.location.href=document.getElementById('btn2action').value\" id=\"btn2\" value=\"nur ".pers_initialen($persid)." l&ouml;schen\" /></td></tr>\n";
echo "</table>\n";
echo "<script type=\"text/javascript\"><!--\n";
echo "  function stwConfirm(del_url,del) {\n";
echo "    pos = del_url.indexOf('ktyp');\n";
echo "    if(pos > 1) {\n";
echo "      var ktyp = del_url.substr(pos+5,1);\n";
echo "      if(ktyp=='t') document.getElementById('btn1').value = unescape('Sitzung l%F6schen');\n";
echo "    }\n";
echo "    window.scrollTo(0,0);\n";
echo "    document.getElementById('btn1').disabled = del==1 ? false : 'disabled';\n";
echo "    document.getElementById('btn1').style.color = del==1 ? 'black' : 'grey';\n";
echo "    var pos = del_url.indexOf('loc=kal');\n";
echo "    if(pos == -1) return true;\n";
echo "    if(pos > 1) {\n";
echo "      if(ktyp!='1' && ktyp!='t' && ktyp!='l' && ktyp!='g') return true;\n";
echo "    }\n";
echo "    document.getElementById('stwDialog').style.display = 'block';\n";
echo "    document.getElementById('btn2action').value = del_url;\n";
echo "    document.getElementById('btn1action').value = del_url.replace('&loc=kal','');\n";
echo "    return false;\n";
echo "  }\n";
echo "--></script>\n";

?>