<?php
/*******************************************************************************
 * Stellware - Jugendhilfe Management System                                   *
 *                                                                             *
 * Dieses Programm ist Freie Software. Sie koennen es unter den Bedingungen    *
 * der GNU General Public License (GPL), wie von der Free Software Foundation  *
 * veroeffentlicht, weitergeben und/oder modifizieren, entweder gemaess        *
 * Version 2 der Lizenz oder, wenn Sie das wuenschen, nach jeder spaeteren     *
 * Version.                                                                    *
 *                                                                             *
 * Die Veroeffentlichung dieses Programmes erfolgt in der Hoffnung, dass es    *
 * Ihnen von Nutzen sein wird, aber ohne irgendeine Garantie, auch ohne die    *
 * implizite Garantie der Marktreife oder Verwendbarkeit fuer irgendeinen      *
 * bestimmten Zweck. Details finden Sie in der GNU General Public License in   *
 * der Datei 'gpl.txt' im Verzeichnis 'doc'.                                   *
 *                                                                             *
 *  http://www.stellware.de                                                    *
 *******************************************************************************
 *
 * $Id: stwDaten.inc.php 2926 2018-12-19 16:04:31Z tfreudenberg $
 *
 */

 /* Datei befindet sich in inc - Dateiname und Verzeichnis entfernen */
 $pfad = substr(__FILE__, 0, strlen(__FILE__) - 20);
 require_once($pfad."inc/func.inc.php");

 /*
  * Klasse stwDaten stellt eine Abbildung der Dateien dar. Innerhalb einer
  * Instanz kann es mehrere Dateien geben. Eindeutig zusammengefasst sind
  * sie unter einer ZahlenId.
  */
 class stwDaten
 {
   var $rechte_id; /* die verwaltete RechteId */
   var $seite;     /* Seitenbereichszahl */

   var $name;      /* Seitenname auf die sich hier bezogen wird */
   var $rname;     /* Rechtename der vom Nutzer festgelegt wurde */

   var $rseite;    /* Anzahl der Eintraege fuer eine kleine Liste */

   var $lsehen;    /* notwendiger Level zum sehen der Dateien */
   var $ldown;     /* notwendiger Level zum Downloaden der Dateien */

   var $lup;       /* notwendiger Level zum Uploaden von Dateien */
   var $ldel;      /* notwendiger Level zum Loeschen von Dateien */

   /*
    * Konstruktor fuer diese Klasse.
    */
   function stwDaten($id)
   {
     /* Vorinitialisierung */
     $this->rechte_id = intval($id);

     /* die anderen Variablen aus der Datenbank holen */
     if ($this->rechte_id > 0)
     {
       $sql  = "SELECT seite, name, rname, rseite, lsehen, ldown, lup, ldel, lzip ";
       $sql .= "FROM tb_daten_rechte WHERE rechte_id='".$this->rechte_id."'";

       $erg = abfrage($sql);
       $this->seite = $erg[0];

       $this->name  = $erg[1];
       $this->rname = $erg[2];

       $this->rseite = $erg[3];
       $this->lsehen = $erg[4];

       $this->ldown = $erg[5];
       $this->lup   = $erg[6];

       $this->ldel  = $erg[7];
       $this->lzip  = $erg[8];
     }
     else
     {
       $this->lsehen = 97;
       $this->ldown  = 97;
       $this->lup   = 97;
       $this->ldel  = 97;
       $this->lzip  = 99;
     }
   }

   /*
    * Ein Klammersymbol soll auf einen Dialog zeigen. Mit dieser
    * Funktion kann der notwendige Link ausgegeben werden. Das Symbol
    * ist zusaetzlich noch eingefaerbt (keine Datei vorhanden: gelb,
    * eine Datei: gruen; mehrere Dateien rot).
    *
    * Zusaetzlich ist es notwendig die aufrufende PersonID und PersonLevel
    * mit anzugeben. Dadurch kann noch ein Rechtecheck durchgefuehrt werden.
    *
    * $webdir: Grundverzeichnis (um Bilder zu finden)
    * $uid:    Person die aufruft
    * $ulv:    Personlevel die aufruft
    * $zahl/zahl2: zu einem Rechteobjekt gehoert noch eine eindeutige Zahl
	* $special_clearance: Sonderrecht, Klammer unabhaengig vom Level zu benutzen
    */
   function get_klammer_link($webdir, $uid, $ulv, $zahl, $zahl2, $special_clearance=false, $stwToolTip=true)
   {
     global $AppCode;
     /* nur wenn gueltige RechteId vorhanden ist. */
     $zahl_id  = intval($zahl);
     $zahl_id2 = intval($zahl2);

     if ($this->rechte_id == 0 || $zahl_id == 0) return "";

	 /* Sonderfreigabe fuer diese Klammer hinzufuegen */
	 $_SESSION[$AppCode][$this->rechte_id][$zahl_id][$zahl_id2] = $special_clearance;

     /* Datenbank nach der Anzahl der Dateien fragen */
     $sql  = "SELECT COUNT(datei_id) FROM tb_daten ";
     $sql .= "WHERE rechte_id='".$this->rechte_id."' ";

     $sql .= "AND zahl_id = '".$zahl."' AND zahl_id2 = '";
     $sql .= $zahl2."' GROUP BY rechte_id";

     $erg  = abfrage($sql);

     if($this->rechte_id == 44 && $erg[0] > 0) {
		$farbe = "pink";
		$titel = ($erg[0] == 1) ? "eine Datei" : "mehrere Dateien";
	 } elseif ($erg[0] > 1) {
       $farbe = "rot";
       $titel = "mehrere Dateien";
     } else {
       if ($erg[0] == 1)
       {
         $farbe = "gruen";
         $titel = "eine Datei";
       }
       else
       {
         $farbe = "gelb";
         $titel = "noch keine Datei";
       }
     }

     /* vielleicht ein Rechtename vorhanden, im Titel mit zeigen */
     $sql  = "SELECT rname FROM tb_daten_rechte WHERE rechte_id='";
     $sql .= $this->rechte_id."'";

     $rname  = abfrage($sql);
     if (!empty($rname[0])) $titel = $rname[0].": ".$titel;

     /*
      * Ausgabe zusammenstellen - oeffnet neues Fenster - nur wenn
      * Recht vorhanden ist.
      */
     if ($this->check_recht_sehen($uid, $ulv, $zahl_id, $zahl_id2))
     {
	   if($erg[0] > 0) {
		  $tt = '<table>';
		  $sql  = "SELECT datei_id, rname, size, datum, pers_id FROM tb_daten ";
		  $sql .= "WHERE rechte_id='".$this->rechte_id."' AND zahl_id='".$zahl_id."' ";
		  $sql .= "AND zahl_id2='".$zahl_id2."' ORDER BY rname ASC";
		  $res = abfrage1($sql);
		  $sql  = "SELECT link, name, datum, pers_id FROM tb_daten_urls ";
		  $sql .= "WHERE rechte_id='".$this->rechte_id."' AND zahl_id='".$zahl_id."' ";
		  $sql .= "AND zahl_id2='".$zahl_id2."' ORDER BY id ASC";
		  $res2 = abfrage1($sql);
		  while($row = mysql_fetch_row($res)) {
			$tt .= "<tr><td><img src=\"".$webdir."/img/daten.png\" /></td><td><a target=\"_blank\" title=\"".date("d.m.Y H:i", $row[3])." &nbsp; ";
			$tt .= pers_kname($row[4])."\" href=\"".$webdir."/daten_down.php?id=$row[0]\" style=\"color:rgb(204,204,204); font-weight:normal; font-style:normal\">$row[1]</a></td>";
			$tt .= "<td style=\"text-align:right\"><img style=\"cursor:pointer\" src=\"".image('copy')."\" name=\"yellow\" ";
			$tt .= "onclick=\"xajax_klammerCopy($row[0])\" ";
			$tt .= "onload=\"if(document.getElementById('copyKlammerId').value == $row[0] && this.name == 'yellow') {this.src=('".image('copy',16,16,0,255,0)."'); this.name='green';} ";
			$tt .= "else if(document.getElementById('copyKlammerId').value != $row[0] && this.name == 'green') {this.src=('".image('copy')."'); this.name='yellow';} \"";
			$tt .= " /></td></tr>";
		  }
		  if(mysql_num_rows($res) > 0 && mysql_num_rows($res2) > 0) $tt .= "<tr><td colspan=\"30\" style=\"background-color:green\"></td></tr>";
		  while($row = mysql_fetch_row($res2)) {
			$tt .= "<tr><td><a href=\"$row[0]\" target=\"_blank\"><img src=\"".$webdir."/img/weltkugel.png\" /></a></td>";
			$tt .= "<td colspan=\"2\"><a title=\"".date("d.m.Y H:i", $row[2])." &nbsp; ";
			$tt .= pers_kname($row[3])."\" href=\"$row[0]\" target=\"_blank\" style=\"color:rgb(204,204,204); font-weight:normal; font-style:normal\">$row[1]</a></td>";
			$tt .= "</tr>";
		  }
		  $tt .= '</table>';
	   }
	   $aus = "<a href=\"".$this->name.".php\" onclick=\"window.open(";
       $aus .= "'".$webdir."/daten_dlg.php?rechte_id=".$this->rechte_id;

       $aus .= "&amp;zahl_id=".$zahl_id."&amp;zahl_id2=".$zahl_id2."', 'Dateien";
       if (!empty($this->rname)) $aus .= " ".$this->rname;

       $aus .= "', 'resizable=yes, left=100, top=50, width=1200, height=500, ";
       $aus .= "menubar=no, status=no, toolbar=no, location=no'); ";

       $aus .= "return false;\"><img border=\"0\" src=\"";
       if (!empty($webdir)) $aus .= $webdir."/";

       $aus .= "img/klammer_".$farbe.".png\" ";
	   if($erg[0] > 0 && $stwToolTip) $aus .= stwToolTipFixed($tt,$titel);
	   else $aus .= $stwToolTip ? stwToolTip($titel) : " title=\"$titel\"";
	   $aus .= "alt=\"Klammer $farbe\"/></a>";
     }
     else
     {
       $aus  = "<img border=\"0\" src=\"";
       if (!empty($webdir)) $aus .= $webdir."/";
       $aus .= "img/klammer_".$farbe.".png\"";
	   $aus .= $stwToolTip ? stwToolTip($titel) : " title=\"$titel\"";
	   $aus .= " alt=\"Klammer $farbe\"/>";
     }

     return $aus;
   }

   /*
    * Ausgabe Klammersymbol ohne Link
    */
   function get_klammer($webdir, $zahl, $zahl2, $stwToolTip=true) {
     $zahl_id  = intval($zahl);
     $zahl_id2 = intval($zahl2);
     /* Datenbank nach der Anzahl der Dateien fragen */
     $sql  = "SELECT COUNT(datei_id) FROM tb_daten ";
     $sql .= "WHERE rechte_id='".$this->rechte_id."' ";
     $sql .= "AND zahl_id = '".$zahl."' AND zahl_id2 = '";
     $sql .= $zahl2."' GROUP BY rechte_id";
     $erg  = abfrage($sql);
     if ($erg[0] > 1) {
       $farbe = "rot";
       $titel = "mehrere Dateien";
     } else {
       if ($erg[0] == 1) {
         $farbe = "gruen";
         $titel = "eine Datei";
       } else {
         $farbe = "gelb";
         $titel = "noch keine Datei";
       }
     }
     /* vielleicht ein Rechtename vorhanden, im Titel mit zeigen */
     $sql  = "SELECT rname FROM tb_daten_rechte WHERE rechte_id='";
     $sql .= $this->rechte_id."'";
     $erg  = abfrage($sql);
     if (!empty($erg[0])) $titel = $erg[0].": ".$titel;
     $aus  = "<img border=\"0\" src=\"";
     if (!empty($webdir)) $aus .= $webdir."/";
     $aus .= "img/klammer_".$farbe.".png\"";
	 $aus .= $stwToolTip ? stwToolTip($titel) : " title=\"$titel\"";
	 $aus .= " alt=\"Klammer $farbe\"/>";
	 return $aus;
   }

   /*
    * Prueft ob der Nutzer dieses Objekt sehen darf und gibt true oder
    * false als Ergebnis zurueck.
    *
    * $pers_id: diese PersonalID verlangt es zu sehen
    * $ulv:     UserLevel
    */
   function check_recht_sehen($pers_id, $ulv, $zahl_id=0, $zahl_id2=0)
   {
     global $AppCode;

     /* Sonderfreigabe? */
     if (is_array($_SESSION[$AppCode][$this->rechte_id]) &&
         array_key_exists($zahl_id, $_SESSION[$AppCode][$this->rechte_id]))
     {
       if ($_SESSION[$AppCode][$this->rechte_id][$zahl_id][$zahl_id2]) return true;
     }

     /* Level pruefen */
     if ($ulv >= $this->lsehen) return true;

     $sql  = "SELECT COUNT(pers_id) FROM tb_daten_pers WHERE ";
     $sql .= "rechte_id = '".$this->rechte_id."' AND pers_id = '".$pers_id."' ";

     $sql .= "AND recht_art >= '0'";
     $erg  = abfrage($sql);

     /* Sonderrecht vorhanden */
     if ($erg[0] > 0) return true;
     return false;
   }

   /*
    * Prueft ob der Nutzer dieses Objekt herunterladen darf und gibt true oder
    * false als Ergebnis zurueck.
    *
    * $pers_id: diese PersonalID verlangt den Download
    * $ulv:     Nutzerlevel
    */
   function check_recht_download($pers_id, $ulv, $zahl_id=0, $zahl_id2=0)
   {
     global $AppCode;

     /* Sonderfreigabe? */
     if (isset($_SESSION[$AppCode]) && isset($_SESSION[$AppCode][$this->rechte_id]) &&
         isset($_SESSION[$AppCode][$this->rechte_id][$zahl_id]) &&
         $_SESSION[$AppCode][$this->rechte_id][$zahl_id][$zahl_id2]) return true;

     /*
      * RechteId 0 kommt im Augenblick nur bei Backups vor. Hat der Nutzer
      * das Recht die Seite zu sehen, kann die Datei heruntergeladen werden.
      */
     if ($this->rechte_id == 0) return true;

     /* Level pruefen */
     if ($ulv >= $this->ldown) return true;

     $sql  = "SELECT COUNT(pers_id) FROM tb_daten_pers WHERE ";
     $sql .= "rechte_id = '".$this->rechte_id."' AND pers_id = '".$pers_id."' ";

     $sql .= "AND recht_art in ('1','4')";
     $erg  = abfrage($sql);

     /* Sonderrecht vorhanden */
     if ($erg[0] > 0) return true;
     return false;
   }

   /*
    * Prueft ob der Nutzer dieses Objekt als Zip-Archiv herunterladen
    * darf und gibt true oder false als Ergebnis zurueck.
    *
    * $pers_id: diese PersonalID verlangt den Download
    * $ulv:     Nutzerlevel
    */
   function check_recht_zip($pers_id, $ulv, $zahl_id=0, $zahl_id2=0)
   {
     /* Level pruefen */
     if ($ulv >= $this->lzip) return true;

     $sql  = "SELECT COUNT(pers_id) FROM tb_daten_pers WHERE ";
     $sql .= "rechte_id = '".$this->rechte_id."' AND pers_id = '".$pers_id."' ";
     $sql .= "AND recht_art = '4'";
     $erg  = abfrage($sql);

     /* Sonderrecht vorhanden */
     if ($erg[0] > 0) return true;
     return false;
   }

   /*
    * Prueft ob der Nutzer in dieses Objekt hochladen darf und gibt true oder
    * false als Ergebnis zurueck.
    *
    * $pers_id: diese PersonalID verlangt den Upload
    * $ulv:     Nutzerlevel
    */
   function check_recht_upload($pers_id, $ulv, $zahl_id=0, $zahl_id2=0)
   {
     global $AppCode;
     /* Sonderfreigabe? */
     if ($_SESSION[$AppCode][$this->rechte_id][$zahl_id][$zahl_id2]) return true;

     /* Level pruefen */
     if ($ulv >= $this->lup) return true;

     $sql  = "SELECT COUNT(pers_id) FROM tb_daten_pers WHERE ";
     $sql .= "rechte_id = '".$this->rechte_id."' AND pers_id = '".$pers_id."' ";

     $sql .= "AND recht_art = '2'";
     $erg  = abfrage($sql);

     /* Sonderrecht vorhanden */
     if ($erg[0] > 0) return true;
     return false;
   }

   /*
    * Prueft ob der Nutzer in diesem Objekt loeschen darf und gibt true oder
    * false als Ergebnis zurueck.
    *
    * $pers_id: diese PersonalID verlangt das Loeschen
    * $ulv:     Nutzerlevel
    */
   function check_recht_del($pers_id, $ulv)
   {
     /* Level pruefen */
     if ($ulv >= $this->ldel) return true;

     $sql  = "SELECT COUNT(pers_id) FROM tb_daten_pers WHERE ";
     $sql .= "rechte_id = '".$this->rechte_id."' AND pers_id = '".$pers_id."' ";

     $sql .= "AND recht_art = '3'";
     $erg  = abfrage($sql);

     /* Sonderrecht vorhanden */
     if ($erg[0] > 0) return true;
     return false;
   }

   /*
    * Liefert die eigene RechteId.
    */
   function get_id()
   {
     return $this->rechte_id;
   }

   /*
    * Alle Dateien zu einer bestimmten Zahl loeschen.
    */
   function delete_dateien($zahl, $zahl2)
   {
     if (empty($zahl)) return;

     $sql  = "SELECT sname, datum FROM tb_daten WHERE ";
     $sql .= "rechte_id='".$this->rechte_id."' AND zahl_id='".$zahl."' ";

     $sql .= "AND zahl_id2 = '".$zahl2."'";
     $erg = abfrage1($sql);

     while ($zeile = mysql_fetch_row($erg))
     {
       $ret = unlink($pfad."daten/".$zeile[1]."_".$zeile[0]);
     }

     $sql  = "DELETE FROM tb_daten WHERE rechte_id='".$this->rechte_id."' AND ";
     $sql .= "zahl_id = '".$zahl."' AND zahl_id2 = '".$zahl2."'";

     abfrage2($sql);
   }
 }

?>
