<?php
/*******************************************************************************
 * Stellware - Jugendhilfe Management System                                   *
 *                                                                             *
 * Dieses Programm ist Freie Software. Sie koennen es unter den Bedingungen    *
 * der GNU General Public License (GPL), wie von der Free Software Foundation  *
 * veroeffentlicht, weitergeben und/oder modifizieren, entweder gemaess        *
 * Version 2 der Lizenz oder, wenn Sie das wuenschen, nach jeder spaeteren     *
 * Version.                                                                    *
 *                                                                             *
 * Die Veroeffentlichung dieses Programmes erfolgt in der Hoffnung, dass es    *
 * Ihnen von Nutzen sein wird, aber ohne irgendeine Garantie, auch ohne die    *
 * implizite Garantie der Marktreife oder Verwendbarkeit fuer irgendeinen      *
 * bestimmten Zweck. Details finden Sie in der GNU General Public License in   *
 * der Datei 'gpl.txt' im Verzeichnis 'doc'.                                   *
 *                                                                             *
 *  http://www.stellware.de                                                    *
 *******************************************************************************
 *
 * $Id: svn.inc.php 2695 2017-02-01 11:42:13Z tfreudenberg $
 *
 */

 /* Datei befindet sich in inc - Dateiname und Verzeichnis entfernen */
 $pfad = substr(__FILE__, 0, strlen(__FILE__) - 15);
 require($pfad."conf/conf.inc.php");

 /* globale Cachevariablen fuer den SVN Bereich */
 $svn_db      = "";

 /*
  * stwSVN ist die Klasse die den Clientzugriff auf einen SVN Server
  * realisiert. Moeglich sind verschiedene Abfragen wie Versionen oder
  * Logeintraege. Dateien sind auch aus dem Server beziehbar.
  */
 class stwSVN
 {
   var $url; /* Speichert die Verbindung zum Server */

   var $cache_version; /* Zwischenspeicher letzte Version */
   var $cache_author;  /* Zwischenspeicher zur letzten Version Author */

   var $cache_message; /* Zwischenspeicher zur letzten Version Nachricht */
   var $cache_date;    /* Zwischenspeicher zur letzten Version Datum */

   var $server; /* Serveradresse speichern */
   var $repo;   /* Pfad speichern */

   var $port;   /* Port zum Server */
   var $login;  /* Logindaten fuer den SVN Server */

   var $pwd;    /* Passwort fuer den SVN Server */

   /*
    * Konstruktor der Klasse der die Verbindung zum Server aufbaut und das
    * SVN Protokoll bis zur Kommandoeingabe fuehrt.
    */
   function stwSVN($serverliste, $port, $repo, $login = "", $pwd = "")
   {
     /* Cache initialisieren */
     $this->cache_version = 0;
     $this->cache_author  = "";

     $this->cache_message = "";
     $this->cache_date    = "";

     $this->serverliste = $serverliste;
     $this->repo   = $repo;

     $this->port   = $port;
     $this->login  = $login;

     $this->pwd    = $pwd;
     return $this->open_connection();
   }

   /*
    * Verbindung zum Subversion Server aufbauen.
    */
   function open_connection() {
	/* Verbindung zum Server aufbauen
	 * dazu die Serverliste durchgehen und beim
	 * ersten erfolgreichen Aufbau raus
	 */
	foreach ($this->serverliste as $server) {
		$this->url = fsockopen($server, $this->port, $errno, $errstr, 2);
		if ($this->url) {
			break;
	/*	} else {
			echo "<h1 style=\"color:red\">FEHLER beim Herstellen der SVN-Verbindung zu ".$server.":</h1>".$errno."-".$errstr;
	*/
		}
	}

     /*
      * Die unterstuetzten Versionen und Moeglichkeiten holen. Antwort
      * sieht nach Verbindungsaufbau z.B. so aus:
      * ( success ( 1 2 ( ANONYMOUS ) ( edit-pipeline svndiff1
      * absent-entries ) ) )
      */
     $str = $this->get_answer();
     if (strpos($str, "( success ( ") === false) return false;

     /* die Antwort schicken was wir alles koennen */
     $antwort = "svn://".$this->server."/".$this->repo;
     $antwort = strlen($antwort).":".$antwort;

     $antwort = "( 2 ( edit-pipeline svndiff1 absent-entries ) ".$antwort." ) ";
     fputs($this->url, $antwort);

     /*
      * Antwort vom Server wie die Zugriffsrechte auf Server fuer Repository
      * deklariert ist.
      * z.B: ( success ( ( ANONYMOUS CRAM-MD5 ) 20:Stellware Repository ) )
      */
     $str = $this->get_answer();
     if (strpos($str, "( success ( ") === false ||
         strpos($str, "ANONYMOUS") === false) return false;

     /* jetzt muss die Anmeldung folgen */
     if (empty($this->login) || empty($this->pwd))
     {
       fputs($this->url, "( ANONYMOUS ( 0: ) ) ");

       /* neue Antwort vom Server - setzt sich aus zwei Nachrichten zusammen */
       $str = $this->get_answer().$this->get_answer();
       if (strpos($str, "( success ( ") === false) return false;
     }
     else
     {
       fputs($this->url, "( CRAM-MD5 ( ) ) ");

       /* neue Antwort vom Server mit der Challenge */
       $str = $this->get_answer();
       if (strpos($str, "( step ( ") === false) return false;

       $pos = strpos($str, "<");
       $challenge = substr($str, $pos, strpos($str, ">") - $pos + 1);

       $se = $this->login." ".hash_hmac("MD5", $challenge, $this->pwd);
       fputs($this->url, strlen($se).":".$se." ");

       /* zwei Antworten vom Server holen */
       $str = $this->get_answer().$this->get_answer();
       if (strpos($str, "( success ( ") === false) return false;
     }
   }

   /*
    * Schliesst die Verbindung zum Subversion Server.
    */
   function close_connection()
   {
     fclose($this->url);
     $this->url = false;
   }

   /*
    * Laenge aus Zeichenkette ermitteln.
    */
   function get_string_length($str)
   {
     /* Zahl ermitteln die vor dem Doppelpunkt steht */
     $raus = 0;
     $pos  = strlen($str) - 2;

     do
     {
       if (!($str[$pos] >= "0" && $str[$pos] <= "9")) $raus = 1;
       $pos--;

     } while ($raus == 0);

     return substr($str, $pos + 2, strlen($text) - 1);
   }

   /*
    * Holt eine Antworten vom Server (eine Klammerung) und gibt sie als
    * Zeichenkette zurueck.
    */
   function get_answer()
   {
     $text = "";
     $klammer_count = 0;

     do
     {
       /* ein Zeichen holen */
       $zeichen = fgetc($this->url);

       /* oeffnende Klammer -> Count erhoehen */
       if ($zeichen == "(") $klammer_count++;

       /* schliessende Klammer -> Count abziehen */
       if ($zeichen == ")") $klammer_count--;

       /* ausgelesenes Zeichen anhaengen */
       $text .= $zeichen;

       /*
        * Zeichenketten gesondert einlesen, weil Klammern enthalten sein
        * koennten.
        */
       if ($zeichen == ":")
       {
         /* Zahl ermitteln die vor dem Doppelpunkt steht */
         $length = $this->get_string_length($text);

         /* so viele Zeichen einlesen */
         for ($i = $length; $i > 0; --$i) $text .= fgetc($this->url);
       }

     } while ($klammer_count > 0);

     /* letztes Zeichen noch holen */
     $zeichen = fgetc($this->url);
     $text   .= $zeichen;

     return $text;
   }

   /*
    * Holt eine Zeichenkette die mit einer Laengenangabe startet.
    */
   function get_inhalt()
   {
     $length = "";
     $inhalt = "";

     $raus = 0;
     $zeile = "";

     do
     {
       /* ein Zeichen holen */
       $zeichen = fgetc($this->url);

       if ($zeichen == ":")
       {
         if ($length == "0")
         {
           for ($i = 1; $i < 18; $i++) $zeile .= fgetc($this->url);
           if (strpos($zeile, " ( success ( ) ) ") === false) return false;

           $raus = 1;
         }
         else
         {
           for ($i = 0; $i < $length; $i++) $inhalt .= fgetc($this->url);
           if (fgetc($this->url) != " ") return false;
         }

         $length = "";
         $zeichen = "";
       }
       else
       {
         $length .= $zeichen;
       }

     } while ($raus == 0);

     return $inhalt;
   }

   /*
    * Die Serverversion holen.
    */
   function get_server_version()
   {
     /* letzte Revisionsnummer holen */
     fputs($this->url, "( get-latest-rev ( ) ) ");

     /* 2 Antworten holen */
     $str = $this->get_answer();
     if (strpos($str, "( success ( ( ) 0: ) ) ") === false) return false;

     $str = $this->get_answer();
     if (strpos($str, "( success ( ") === false) return false;

     $version = substr($str, 12);
     $version = substr($version, 0, strlen($version) - 5);

     return $version;
   }

   /*
    * Manche Antworten vom Server sind nur das Wort "done".
    */
   function get_answer_done()
   {
     $text = "";
     for ($i = 0; $i < 5; $i++) $text .= fgetc($this->url);

     return $text;
   }

   /*
    * Logkommando absetzen und auswerten.
    */
   function log_kommando($version)
   {
     /* Server das Logkommando schicken. */
     $str  = "( log ( ( 0: ) ( ".$version." ) ( ".$version;
     $str .= " ) false false 0 ) ) ";

     fputs($this->url, $str);

     /*
      * Antwort holen - muss Erfolg sein der wie folgt aussieht:
      * ( success ( ( ) 0: ) )
      */
     $str = $this->get_answer();
     if (strpos($str, "( success ( ( ) 0: ) ) ") === false) return false;

     /* Informationen holen */
     $eintraege = $this->get_answer();

     /* done Nachricht holen */
     $str = $this->get_answer_done();
     if (strpos($str, "done ") === false) return false;

     /* Erfolgsmeldung holen */
     $str = $this->get_answer();
     if (strpos($str, "( success ( ) ) ") === false) return false;

     /* die erhaltenen Informationen verarbeiten */
     $pos = -1; do $pos++; while ($eintraege[$pos] != ":"); $pos++;

     /* Author ermitteln */
     $length = $this->get_string_length(substr($eintraege, 0, $pos));
     $this->cache_author = substr($eintraege, $pos, $length);

     /* Zeitstempel holen */
     $pos += $length;
     do $pos++; while ($eintraege[$pos] != ":"); $pos++;

     $length = $this->get_string_length(substr($eintraege, 0, $pos));
     $this->cache_date = substr($eintraege, $pos, $length);

     /* Datum noch umstellen auf deutsches Format */
     $feld = explode("T", $this->cache_date);
     $datum_feld = explode("-", $feld[0]);

     $this->cache_date  = $datum_feld[2].".".$datum_feld[1].".";
     $this->cache_date .= $datum_feld[0]." ";

     $zeit_feld = explode(".", $feld[1]);
     $this->cache_date .= $zeit_feld[0];

     /* Logmeldung holen */
     $pos += $length;
     do $pos++; while ($eintraege[$pos] != ":"); $pos++;

     $length = $this->get_string_length(substr($eintraege, 0, $pos));
     $this->cache_message = substr($eintraege, $pos, $length);

     /* alle Cache Eintraege vollstaendig */
     $this->cache_version = $version;
   }

   /*
    * Holt das Datum fuer einen Logeintrag vom Server
    * fuer die gewuenschte Version.
    */
   function log_date($version)
   {
     /* pruefen ob vielleicht schon im Cache vorhanden */
     if ($this->cache_version == $version) return $this->cache_date;

     /* Cache aktualisieren fuer dieses Objekt */
     $this->log_kommando($version);
     return $this->cache_date;
   }

   /*
    * Holt den Author fuer einen Logeintrag vom Server
    * fuer die gewuenschte Version.
    */
   function log_author($version)
   {
     /* pruefen ob vielleicht schon im Cache vorhanden */
     if ($this->cache_version == $version) return $this->cache_author;

     /* Cache aktualisieren fuer dieses Objekt */
     $this->log_kommando($version);
     return $this->cache_author;
   }

   /*
    * Holt die Logmeldung fuer einen Logeintrag vom Server
    * fuer die gewuenschte Version.
    */
   function log_message($version)
   {
     /* pruefen ob vielleicht schon im Cache vorhanden */
     if ($this->cache_version == $version) return $this->cache_message;

     /* Cache aktualisieren fuer dieses Objekt */
     $this->log_kommando($version);
     return $this->cache_message;
   }

   /*
    * Ermittelt die geaenderten Dateien zwischen den beiden Versionen.
    */
   function changed_files($alt, $neu)
   {
     /* Server das Updatekommando schicken */
     $str = "( update ( ( ".$neu." ) 0: true ) ) ";
     fputs($this->url, $str);

     /* Antwort holen: ( success ( ( ) 0: ) ) */
     $str = $this->get_answer();
     if (strpos($str, "( success ( ( ) 0: ) ) ") === false) return false;

     /* Ausgangsversion setzen */
     $str = "( set-path ( 0: ".$alt." false ( ) ) ) ( finish-report ( ) ) ";
     fputs($this->url, $str);

     /* Unterschied holen */
     $files = array();
     $delete = array();

     $add_dir = array();

     $raus = 0;
     do
     {
       $str = $this->get_answer();

       if (strpos($str, "( open-file ( ") !== false ||
           strpos($str, "( add-file ( ") !== false)
       {
         /* eine vorhandene Datei wurde geaendert */
         $pos = 0;
         do $pos++; while ($str[$pos] != ":"); $pos++;

         $length = $this->get_string_length(substr($str, 0, $pos));
         $files[] = substr($str, $pos, $length);
       }

       if (strpos($str, "( delete-entry ( ") !== false)
       {
         /* eine Datei oder ein Verzeichnis wurde geloescht */
         $pos = 0;
         do $pos++; while ($str[$pos] != ":"); $pos++;

         $length = $this->get_string_length(substr($str, 0, $pos));
         $delete[] = substr($str, $pos, $length);
       }

       if (strpos($str, "( add-dir ( ") !== false)
       {
         /* Verzeichnis angelegt */
         $pos = 0;
         do $pos++; while ($str[$pos] != ":"); $pos++;

         $length = $this->get_string_length(substr($str, 0, $pos));
         $add_dir[] = substr($str, $pos, $length);
       }

       /* Antworten holen bis Editormodus geschlossen wird */
       if (strpos($str, "( close-edit ( ) ) ") !== false) $raus = 1;

     } while ($raus == 0);

     /* Rueckmeldung: ( success ( ) ) */
     fputs($this->url, "( success ( ) ) ");

     /* Server liefert: ( success ( ) ) */
     $str = $this->get_answer();
     if (strpos($str, "( success ( ) ) ") === false) return false;

     $ergebnis["files"] = $files;
     $ergebnis["delete"] = $delete;

     $ergebnis["add_dir"] = $add_dir;
     return $ergebnis;
   }

   /*
    * Fuehrt ein Update auf eine neue Version durch.
    */
   function update($alt, $neu)
   {
     $ergebnis = $this->changed_files($alt, $neu);
     $files = $ergebnis["files"];

     $delete = $ergebnis["delete"];
     $add_dir = $ergebnis["add_dir"];

     /* vollstaendigen Pfad zusammenstellen */
     $pfad = substr(__FILE__, 0, strlen(__FILE__) - 15);

     /* Verzeichnisse hinzufuegen */
     foreach ($add_dir as $verzeichnis)
     {
       /* Verzeichnis anlegen falls noch nicht vorhanden */
       if (!is_dir($pfad.$verzeichnis)) mkdir($pfad.$verzeichnis, 0700, true);
     }

     /* alle Dateiinhalte holen */
     foreach ($files as $datei)
     {
       /* Server mitteilen welche Datei gewuenscht ist */
       $dat = "svn://".$this->server."/".$this->repo."/".$datei;
       $str = "( reparent ( ".strlen($dat).":".$dat." ) ) ";

       /* Kommando abschicken */
       fputs($this->url, $str);

       /* Server liefert: ( success ( ( ) 0: ) ) ( success ( ) ) */
       $str = $this->get_answer().$this->get_answer();
       if (strpos($str, "( success ( ( ) 0: ) ) ( success ( ) ) ") === false)
       {
         return false;
       }

       /* get-file Kommando abschicken */
       $str = "( get-file ( 0: ( ".$neu." ) false true ) ) ";
       fputs($this->url, $str);

       /* Erfolgsmeldung holen */
       $str = $this->get_answer().$this->get_answer();

       if (strpos($str, "( success ( ( ) 0: ) ) ") === false) return false;
       $pfad = substr(__FILE__, 0, strlen(__FILE__) - 15);

       $fp = fopen($pfad.$datei, "wb");
       if (!$fp) return false;

       fwrite($fp, $this->get_inhalt());
       fclose($fp);
     }

     /* Verzeichnis oder Datei loeschen */
     foreach ($delete as $dat)
     {
       if (is_dir($dat))
       {
         /* Verzeichnis wird geloescht */
         rmdir($dat);
       }
       else
       {
         /* Datei wird geloescht */
         unlink($dat);
       }
     }
   }
 }

 /*
  * Datenbankzugriffe die innerhalb der SVN Funktionen notwendig sind.
  */
 function svn_db_query($sql)
 {
   global $conf_srv;
   global $conf_dbn;

   global $conf_dbu;
   global $conf_dbp;
   global $svn_db;

   /* sichergehen das eine Anweisung geschickt wurde */
   if (empty($sql)) return false;

   /* Datenbankverbindung herstellen - wenn globale Variable leer */
   if (empty($svn_db))
   {
     $svn_db = mysql_connect($conf_srv, $conf_dbu, $conf_dbp);
     if (!$svn_db) return false;

     /* Datenbank waehlen */
     $erg = mysql_select_db($conf_dbn, $svn_db);
     if (!$erg) return false;
   }

   /* ausfuehren der Anweisung */
   $res = mysql_query($sql, $svn_db);
   if (!$res) return false;

   return $res;
 }

 /*
  * Es wird die aktuelle Subversion Version ermittelt und als Ergebnis
  * zurueckgeliefert. Im Fehlerfall ist dies eine Null.
  */
 function svn_get_lokal_version()
 {
   $sql = "SELECT svn_id FROM tb_svn ORDER BY datum DESC LIMIT 1";
   $erg = svn_db_query($sql);

   if ($erg && mysql_num_rows($erg) == 1)
   {
     $zeile = mysql_fetch_row($erg);
     return $zeile[0];
   }
   else
   {
     return 0;
   }
 }

 /*
  * Innerhalb der SVN Tabelle soll eine Notiz fuer eine bestimmte Version
  * gesetzt werden. Es kann schon ein Eintrag vorhanden sein oder ein neuer
  * soll erstellt werden.
  */
 function svn_set_tb_notiz($id, $notiz)
 {
   /* pruefen ob die Variablen gefuellt sind */
   if (empty($id) || empty($notiz)) return false;

   /* ist schon ein Eintrag vorhanden */
   $sql = "SELECT svn_id FROM tb_svn WHERE svn_id='".$id."'";
   $res = svn_db_query($sql);

   if ($res)
   {
     if (mysql_num_rows($res) > 0)
     {
       $sql = "UPDATE tb_svn SET notiz='".$notiz."' WHERE svn_id='".$id."'";
     }
     else
     {
       $sql = "INSERT INTO tb_svn SET svn_id='".$id."', notiz='".$notiz."'";
     }

     /* kein Check weil nicht behandelt werden kann */
     svn_db_query($sql);
   }
 }

 /*
  * Setzt einen Zeitstempel fuer die SVN Versionsnummer.
  */
 function svn_set_timestamp($version)
 {
   global $AppCode;

   /* pruefen ob die Variablen gefuellt sind */
   if (empty($version)) return false;

   /* ist schon ein Eintrag vorhanden */
   $sql = "SELECT svn_id FROM tb_svn WHERE svn_id='".$version."'";
   $res = svn_db_query($sql);

   if ($res)
   {
     if (mysql_num_rows($res) > 0)
     {
       $sql  = "UPDATE tb_svn SET datum='".time()."', pers_id='{$_SESSION[$AppCode]["UID"]}' WHERE svn_id='";
       $sql .= $version."'";
     }
     else
     {
       $sql  = "INSERT INTO tb_svn SET svn_id='".$version."', datum='";
       $sql .= time()."', pers_id='{$_SESSION[$AppCode]["UID"]}'";
     }

     /* kein Check weil nicht behandelt werden kann */
     svn_db_query($sql);
   }
 }

?>
